-- Here are the configurable settings.
creative_mode_config = {}

-- Miscellaneous settings
creative_mode_config.misc =
{	
	-- Whether the following settings should be preserved for the same game once they are loaded.
	-- Preserved settings will be applied during the same game and not affected by future update of this mod, unless otherwise specified.
	-- If this is set to false, every time a save is loaded, the game reads this file to get the values.
	-- Please note that not all settings can be preserved due to Factorio's mechanism. The behaviour for each setting is written inside [] in its description.
	-- Even if you set this value to true, you can still type /c remote.call("creative-mode", "update_config") to update the settings.
	-- [Preserved]
	preserve_settings = true,
	
	-- Whether Creative Mode will be automatically enabled with all default cheats for every new game. This doesn't affect existing game that did not have this mod before.
	-- Default cheats include:
	-- 	"Enable all" personal cheats for all existing players.
	--	"Enable all" team cheats for all existing teams.
	--	Always day on all existing surfaces.
	-- [Not preserved]
	auto_enable = false,
	
	-- Whether a popup will be shown to the first player in every new game or any existing game that did not have this mod before asking for enabling Creative Mode.
	-- [Not preserved]
	show_popup_in_new_game = true
}

-- Settings about the creative chest and creative provider chest.
creative_mode_config.creative_provider_chest =
{
	-- Inventory size of creative chest and creative provider chest.
	-- Possible value: 1 - 254
	-- (Factorio only supports maximum inventory size of 255, and we use 1 extra slot as the trash slot. So the maximum value becomes 254.)
	-- Its value affects how many chests you need to place for one item cycle. Larger inventory size means fewer chests are needed.
	-- However, it is also more likely to cause performance issue when hovering the chests.
	-- Changing this value for an existing game will cause item regrouping.
	-- Note: do NOT change it after loading.
	-- [Not preserved]
	-- [Need restart Factorio]
	inventory_size = 150,
	
	-- Whether the chests should contain the hidden items. Some items are hidden for good reasons, like the rocket-part item which is not reasonable if you get it.
	-- Changing this value for an existing game will cause item regrouping.
	-- [Preserved]
	contain_hidden_items = false,
}

-- Settings about the autofill requester chest.
creative_mode_config.autofill_requester_chest =
{
	-- Inventory size of autofill requester chest.
	-- Possible value: 1 - 255.
	-- [Not preserved]
	-- [Need restart Factorio]
	inventory_size = 48,
}

-- Settings about the duplicating chest and duplicating provider chest.
creative_mode_config.duplicating_provider_chest =
{
	-- Inventory size of duplicating chest and duplicating provider chest.
	-- Possible value: 1 - 255
	-- [Not preserved]
	-- [Need restart Factorio]
	inventory_size = 48,
}

-- Settings about the void requester chest.
creative_mode_config.void_requester_chest =
{
	-- Inventory size of void requester chest.
	-- Possible value: 1 - 255
	-- [Not preserved]
	-- [Need restart Factorio]
	inventory_size = 48,
}

-- Settings about the void storage chest.
creative_mode_config.void_storage_chest =
{
	-- Inventory size of void storage chest.
	-- Possible value: 1 - 255
	-- [Not preserved]
	-- [Need restart Factorio]
	inventory_size = 48,
}

-- Settings about the creative cargo wagon.
creative_mode_config.creative_cargo_wagon =
{
	-- Inventory size of creative cargo wagon.
	-- Possible value: 1 - 254
	-- Note: do NOT change it after loading.
	-- [Not preserved]
	-- [Need restart Factorio]
	inventory_size = 200,
	
	-- Whether it should contain the hidden items. Some items are hidden for good reasons, like the rocket-part item which is not reasonable if you get it.
	-- Changing this value for an existing game will cause item regrouping.
	-- [Preserved]
	contain_hidden_items = true,
}

-- Settings about the duplicating cargo wagon.
creative_mode_config.duplicating_cargo_wagon =
{
	-- Inventory size of duplicating cargo wagon.
	-- Possible value: 1 - 255
	-- [Not preserved]
	-- [Need restart Factorio]
	inventory_size = 40,
}

-- Settings about the void cargo wagon.
creative_mode_config.void_cargo_wagon =
{
	-- Inventory size of void cargo wagon.
	-- Possible value: 1 - 255
	-- [Not preserved]
	-- [Need restart Factorio]
	inventory_size = 40,
}

-- Settings about the enemy spawners and worms.
creative_mode_config.enemy_spawners_and_worms =
{
	-- Whether "(Creative Mode)" will be added as the suffix of the enemy spawners and worms provided by this mod, to distinguish them from the natural ones.
	-- [Not preserved]
	-- [Need restart Factorio]
	add_name_suffix = true,
}